@@ -13,6 +13,11 @@ import sys
 from datetime import datetime
 from typing import Dict, List
 
+if sys.version_info >= (3, 8):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -24,11 +29,13 @@ __all__ = (
     "SecretListEntryTypeDef",
     "SecretVersionsListEntryTypeDef",
     "TagTypeDef",
+    "ValidationErrorsEntryTypeDef",
     "CancelRotateSecretResponseTypeDef",
     "CreateSecretResponseTypeDef",
     "DeleteResourcePolicyResponseTypeDef",
     "DeleteSecretResponseTypeDef",
     "DescribeSecretResponseTypeDef",
+    "FilterTypeDef",
     "GetRandomPasswordResponseTypeDef",
     "GetResourcePolicyResponseTypeDef",
     "GetSecretValueResponseTypeDef",
@@ -41,6 +48,7 @@ __all__ = (
     "RotateSecretResponseTypeDef",
     "UpdateSecretResponseTypeDef",
     "UpdateSecretVersionStageResponseTypeDef",
+    "ValidateResourcePolicyResponseTypeDef",
 )
 
 RotationRulesTypeTypeDef = TypedDict(
@@ -64,6 +72,7 @@ SecretListEntryTypeDef = TypedDict(
         "Tags": List["TagTypeDef"],
         "SecretVersionsToStages": Dict[str, List[str]],
         "OwningService": str,
+        "CreatedDate": datetime,
     },
     total=False,
 )
@@ -81,6 +90,10 @@ SecretVersionsListEntryTypeDef = TypedDict(
 
 TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str}, total=False)
 
+ValidationErrorsEntryTypeDef = TypedDict(
+    "ValidationErrorsEntryTypeDef", {"CheckName": str, "ErrorMessage": str}, total=False
+)
+
 CancelRotateSecretResponseTypeDef = TypedDict(
     "CancelRotateSecretResponseTypeDef", {"ARN": str, "Name": str, "VersionId": str}, total=False
 )
@@ -114,10 +127,17 @@ DescribeSecretResponseTypeDef = TypedDict(
         "Tags": List["TagTypeDef"],
         "VersionIdsToStages": Dict[str, List[str]],
         "OwningService": str,
+        "CreatedDate": datetime,
     },
     total=False,
 )
 
+FilterTypeDef = TypedDict(
+    "FilterTypeDef",
+    {"Key": Literal["description", "name", "tag-key", "tag-value", "all"], "Values": List[str]},
+    total=False,
+)
+
 GetRandomPasswordResponseTypeDef = TypedDict(
     "GetRandomPasswordResponseTypeDef", {"RandomPassword": str}, total=False
 )
@@ -183,3 +203,9 @@ UpdateSecretResponseTypeDef = TypedDict(
 UpdateSecretVersionStageResponseTypeDef = TypedDict(
     "UpdateSecretVersionStageResponseTypeDef", {"ARN": str, "Name": str}, total=False
 )
+
+ValidateResourcePolicyResponseTypeDef = TypedDict(
+    "ValidateResourcePolicyResponseTypeDef",
+    {"PolicyValidationPassed": bool, "ValidationErrors": List["ValidationErrorsEntryTypeDef"]},
+    total=False,
+)
